#
# spec file for package orcania
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2018-2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# The naming scheme in non-Mandriva-based distros
%if 0%{!?mklibname:1}
%define mklibname(ds)  lib%{1}%{?2:%{2}}%{-s:-static}%{-d:-devel}
%endif
%if 0%{!?mkrel:1}
%define mkrel(c) %{1}%{?dist}
%endif

%define sover 2_3
%define libname %mklibname %{name} %{sover}
%define develname %mklibname %{name} -d

%if "%{_vendor}" == "openEuler"
# Buggy macros in OpenEuler 24.03.
# Maybe this can be removed for OpenEuler 26.03.
# Unfortunately, I can't find any way to get the version of openEuler.
%undefine cmake_build
%undefine cmake_install
%endif

Name:           orcania
Version:        2.3.4
Release:        %mkrel 1
Summary:        MISC function Library
License:        LGPL-2.1-or-later
Group:          Development/Languages/C and C++
URL:            https://github.com/babelouest/orcania
Source:         https://github.com/babelouest/orcania/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  make
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
Different functions for different purposes but that can be shared
between other projects.

%package -n %libname
Summary:        MISC function library
Group:          System/Libraries

%description -n %libname
Different functions for different purposes but that can be shared
between other projects.

%package -n %develname
Summary:        Header files for orcania
Group:          Development/Libraries/C and C++
Requires:       %libname = %{version}

%description -n %develname
Development and header files for orcania.

%prep
%autosetup -p1

%build
%if 0%{?cmake_build:1}
%cmake
%cmake_build
%else
%cmake -B build
%make_build -C build
%endif

%install
%if 0%{?cmake_install:1}
%cmake_install
%else
%make_install -C build
%endif

%post   -n %libname -p /sbin/ldconfig
%postun -n %libname -p /sbin/ldconfig

%files -n %libname
%doc CHANGELOG.md README.md
%license LICENSE
%{_libdir}/liborcania.so.*

%files -n %develname
%{_bindir}/base64url
%{_mandir}/man1/base64url.1*
%{_includedir}/orcania.h
%{_includedir}/orcania-cfg.h
%{_libdir}/liborcania.so
%{_libdir}/pkgconfig/liborcania.pc
%{_libdir}/cmake/Orcania

%changelog
* Mon Sep 18 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.3
  * Enforce base64decode
* Thu Jan 12 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.2
  * Improve cmake script and MSVC support
  * Build with flag -Wconversion
* Sat Oct 15 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.1
  * Minor bugfixes
* Sat May 28 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.0
  * Add o_base64_encode_alloc, o_base64_decode_alloc,
    o_base64url_encode_alloc, o_base64url_decode_alloc,
    o_base64url_2_base64_alloc, o_base64_2_base64url_alloc.
  * Fix pkg-config file with absolute path for
    CMAKE_INSTALL_{INCLUDE,LIB}DIR.
* Sun Mar 13 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.2
  * Add `o_strnullempty`
  * Breaking: `trimwhitespace` now returns `const char *` instead
    of `char *`, might give compiler warning
  * Refactor `o_base64*` functions
* Sat Jun  5 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.1
  * Add ld flags in liborcania.pc on static build
* Sun Feb 28 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.0
  * Add command-line tool `base64url` which is similar to
    GNU `base64` tool but for `base64url` format.
* Tue Jun 30 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.1
  * Harmonize and fix license
  * Fix doc generator
  * Rework mstrcatf
  * Fix pkgconfig install on Makefile
  * Add simple API documentation summary
* Sat Dec 21 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.1.0
  * Generate documentation via doxygen
  * Add functions `pointer_list_clean_free`,
    `pointer_list_remove_at_free` and
    `pointer_list_remove_pointer_free`
  * `split_string` returns `size_t`
  * Add functions `o_strnchr` and `o_strrnchr`
* Fri Jul 12 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.1
  * Fix double free() on `pointer_list_remove_at`
  * Clean build process
  * Fix config option STRTSR so cmake and makefile will use the
    same name
* Tue Jul  2 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.0
  * Add struct _pointer_list to manage arrays of pointers
  * Add string_array_join, string_array_size
  * Add o_base64url_encode and o_base64url_decode, and
    o_base64url_2_base64 to convert base64 url format to base64
  * Remove jansson related functions and dependency
* Fri Dec 28 2018 mardnh@gmx.de
- Update to version 1.2.9
  * Fix build with Makefile.
  * Improve build config file and install headers.
  * Add config file orcania-cfg.h dynamically built with the options.
  * Fix pkgconfig file
  * Fix CMake build when /usr/local is not present in default build
    path.
  * Fix Makefile soname.
- Remove patches:
  * 0001-Fix-pkg-config-information-add-requires-fields-as-me.patch
  * 0002-Fix-pkg-config-got-mixed-between-requires-and-requir.patch
  * orcania-fix-build.patch
* Sat Aug 11 2018 jengelh@inai.de
- Update summaries.
* Fri Aug  3 2018 mardnh@gmx.de
- Add patch:
  * 0001-Fix-pkg-config-information-add-requires-fields-as-me.patch
  * 0002-Fix-pkg-config-got-mixed-between-requires-and-requir.patch
* Sun Jul 29 2018 mardnh@gmx.de
- Initial package, version 1.2.4
